package
Version:
v0.0.0-...-6582c30
Opens a new window with list of versions in this module.
Published: Aug 16, 2017
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 12
Opens a new window with list of known importers.
Documentation
¶
Package logging provides a simple logger interface
type Logger interface {
Debug(v ...interface{})
Info(v ...interface{})
Warning(v ...interface{})
Error(v ...interface{})
Critical(v ...interface{})
Fatal(v ...interface{})
}
Logger collects logging information at several levels
Source Files
¶
Directories
¶
Package gologging provides a logger implementation based on the github.com/op/go-logging pkg
|
Package gologging provides a logger implementation based on the github.com/op/go-logging pkg |
Click to show internal directories.
Click to hide internal directories.